anonymise_dataset: Function to anonymise dataset

Description Usage Arguments Value Author(s) References

View source: R/dataframe_anonymiser.R

Description

The following function removes all the assigned sensitive informations from the raw dataset

Usage

1
anonymise_dataset(data, variables_to_remove = c())

Arguments

data

the dataset you wish to anonymise

variables_to_remove

the names of the sensitive variables you want to remove

Value

An anonymised dataset

Author(s)

Alberto Gualtieri, alberto.gualtieri@reach-initiative.org

References

https://github.com/agualtieri/mcla_cleaneR


agualtieri/dataqualitycontrol documentation built on Aug. 22, 2019, 9:58 p.m.