quality_checks_log_to_long_format: Function to melt quality check log from long to wide

Description Usage Arguments Value Author(s) References

View source: R/quality_log_to_long_format.R

Description

The following function turns the quality check output from wide to long format.

Usage

1
2
quality_checks_log_to_long_format(data, variable_name = "variable",
  value_name = "value", meta_not_to_transform = c())

Arguments

data

the dataset you wish to transform from wide to long

variable_name

the name of the measured variable. The default name is 'variable'

value_name

name of the transformed data value. The default name is 'value'

meta_not_to_transform

a list of metadata you wish to keep as id variables.

Value

A transformed quality check log

Author(s)

Alberto Gualtieri, alberto.gualtieri@reach-initiative.org

References

https://github.com/agualtieri/dataqualitycontrol


agualtieri/dataqualitycontrol documentation built on Aug. 22, 2019, 9:58 p.m.