run_checks_from_dataframe: Run predefined quality check test on a raw dataset

Description Usage Arguments Details Value Author(s) References

View source: R/batch_quality_check.R

Description

The following function checks for the presence of invalid data quality combinations within a dataframe using the supplied condition_list.

Usage

1
2
run_checks_from_dataframe(df, conditions_df, condition.column,
  test.name.column, meta_to_keep = c())

Arguments

df

the dataset you wish to check for invalid combinations of variables

conditions_df

the dataframe contaning the name of the checks and the list of controls to perform

condition.column

the column name that containes the conditions you want to check in the dataset

test.name.column

the column name that contains the description of the checks you want to perform

meta_to_keep

a list of metadata you wish to include in the final output

Details

The condition_list must be a dataframe containingat least two variables: condition as the name of the condition one wishes to check and test as the test applied to each condition.

Value

Standardized issues table for quality check in long format.

Author(s)

Alberto Gualtieri, alberto.gualtieri@reach-initiative.org

References

https://github.com/agualtieri/dataqualitycontrol


agualtieri/dataqualitycontrol documentation built on Aug. 22, 2019, 9:58 p.m.