Description Usage Arguments Value Author(s) References
View source: R/dataframe_anonymiser.R
The following function removes all the assigned sensitive informations from the raw dataset
1 | anonymise_dataset(data, variables_to_remove = c())
|
data |
the dataset you wish to anonymise |
variables_to_remove |
the names of the sensitive variables you want to remove |
An anonymised dataset
Alberto Gualtieri, alberto.gualtieri@reach-initiative.org
https://github.com/agualtieri/mcla_cleaneR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.