Description Usage Arguments Value Author(s) References
View source: R/quality_log_to_long_format.R
The following function turns the quality check output from wide to long format.
1 2 | quality_checks_log_to_long_format(data, variable_name = "variable",
value_name = "value", meta_not_to_transform = c())
|
data |
the dataset you wish to transform from wide to long |
variable_name |
the name of the measured variable. The default name is 'variable' |
value_name |
name of the transformed data value. The default name is 'value' |
meta_not_to_transform |
a list of metadata you wish to keep as id variables. |
A transformed quality check log
Alberto Gualtieri, alberto.gualtieri@reach-initiative.org
https://github.com/agualtieri/dataqualitycontrol
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.