Description Usage Arguments Details Value Author(s) References
View source: R/batch_quality_check.R
The following function checks for the presence of invalid data quality combinations within a dataframe using the supplied condition_list.
1 2 | run_checks_from_dataframe(df, conditions_df, condition.column,
test.name.column, meta_to_keep = c())
|
df |
the dataset you wish to check for invalid combinations of variables |
conditions_df |
the dataframe contaning the name of the checks and the list of controls to perform |
condition.column |
the column name that containes the conditions you want to check in the dataset |
test.name.column |
the column name that contains the description of the checks you want to perform |
meta_to_keep |
a list of metadata you wish to include in the final output |
The condition_list must be a dataframe containingat least two variables: condition as the name of the condition one wishes to check and test as the test applied to each condition.
Standardized issues table for quality check in long format.
Alberto Gualtieri, alberto.gualtieri@reach-initiative.org
https://github.com/agualtieri/dataqualitycontrol
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.